@@ -26,6 +26,7 @@
 #ifdef HAVE_OPENMP
 #include <omp.h>
 #endif
+#include <stdbool.h>
 
 #include "clustal-omega-config.h"
 
@@ -62,6 +63,9 @@
 
 extern int iNumberOfThreads;
 
+/* output order */
+enum {INPUT_ORDER = 0, TREE_ORDER};
+
 
 /** user/commandline options
  *
@@ -85,6 +89,10 @@ typedef struct {
      */
     /** clustering type (from cmdline arg) */
     int iClusteringType;
+    /** number of sequences in cluster */
+    int iClustersizes; 
+    /** file with clustering information */
+    char *pcClustfile; 
     /** pairwise distance method */
     int iPairDistType;
     /** use mbed-like clustering */
@@ -95,7 +103,11 @@ typedef struct {
     char *pcGuidetreeOutfile;
     /** guidetree input file */
     char *pcGuidetreeInfile;
-    
+    /** use Kimura corrected distance */
+    bool bUseKimura;
+    /** print percentage identity */
+    bool bPercID;
+
     /* HMMs
      */
     /** HMM input files. index range: 0..iHMMInputFiles */
@@ -148,8 +160,9 @@ SequentialAlignmentOrder(int **piOrderLR_p, int iNumSeq);
 extern int
 AlignmentOrder(int **piOrderLR_p, double **pdSeqWeights_p, mseq_t *prMSeq,
                int iPairDistType, char *pcDistmatInfile, char *pcDistmatOutfile,
-               int iClusteringType, char *pcGuidetreeInfile, char *pcGuidetreeOutfile,
-               bool bUseMBed);
+               int iClusteringType, int iClustersizes,
+               char *pcGuidetreeInfile, char *pcGuidetreeOutfile, char *pcClusterFile,
+               bool bUseMBed, bool bPercID);
 
 extern int
 Align(mseq_t *prMSeq, 
