@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign_wrapper.c 274 2012-04-24 23:28:24Z dave $
+ *  RCS $Id: hhalign_wrapper.c 284 2013-06-12 10:10:11Z fabian $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -563,8 +563,8 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
      * protein
      */
     if (SEQTYPE_PROTEIN != prMSeq->seqtype) {
-        Log(&rLog, LOG_WARN, "%s alignment is still experimental.",
-             SeqTypeToStr(prMSeq->seqtype));
+        /*Log(&rLog, LOG_WARN, "%s alignment is still experimental.",
+          SeqTypeToStr(prMSeq->seqtype));*/
 		if(prMSeq->seqtype == SEQTYPE_DNA)
 			rHhalignPara.bIsDna = true;
 		if(prMSeq->seqtype == SEQTYPE_RNA)
@@ -765,7 +765,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
-                                         iAux_FS++, /* DEBUG ARGUMENT */
+                                         iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                          zcAux, zcError);
                     }
                     else {
@@ -774,14 +774,15 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
-                                         iAux_FS++, /* DEBUG ARGUMENT */
+                                         iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                          zcAux, zcError);
                     }
-                    if (0 != iHHret){ /* FS, r255 -> */
+                    if ( (0 != iHHret) && (rLog.iLogLevelEnabled <= LOG_VERBOSE) ){ /* FS, r255 -> */
                         fprintf(stderr, "%s:%s:%d: (not essential) HMM pre-alignment failed, error %d, \n"
-                                "\t#=%d (len=%d), lead-seq=%s, len(HMM)=%d\tCARRY ON REGARDLESS\n", 
+                                "\t#=%d (len=%d), lead-seq=%s, len(HMM)=%d\n%s\nCARRY ON REGARDLESS\n", 
                                 __FUNCTION__, __FILE__, __LINE__, iHHret, 
-                                piLeafCount[iL], (int)strlen(ppcCopy1[0]), prMSeq->sqinfo[ppiLeafList[iL][0]].name, (int)strlen(ppcReprsnt1[0]));
+                                piLeafCount[iL], (int)strlen(ppcCopy1[0]), prMSeq->sqinfo[ppiLeafList[iL][0]].name, 
+                                (int)strlen(ppcReprsnt1[0]), zcError);
                     }
                 }
                 pdScores[ppiLeafList[iL][0]] = dScore;
@@ -852,7 +853,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
-                                         iAux_FS++, /* DEBUG ARGUMENT */
+                                         iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                          zcAux, zcError);
                     }
                     else {
@@ -861,14 +862,15 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
-                                         iAux_FS++, /* DEBUG ARGUMENT */
+                                         iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                          zcAux, zcError);
                     }
-                    if (0 != iHHret){ /* FS, r255 -> */
+                    if ( (0 != iHHret) && (rLog.iLogLevelEnabled <= LOG_VERBOSE) ){ /* FS, r255 -> */
                         fprintf(stderr, "%s:%s:%d: (not essential) HMM pre-alignment failed, error %d, \n"
-                                "\t#=%d (len=%d), lead-seq=%s, len(HMM)=%d\tCARRY ON REGARDLESS\n", 
+                                "\t#=%d (len=%d), lead-seq=%s, len(HMM)=%d\n%s\nCARRY ON REGARDLESS\n", 
                                 __FUNCTION__, __FILE__, __LINE__, iHHret, 
-                                piLeafCount[iR], (int)strlen(ppcCopy2[0]), prMSeq->sqinfo[ppiLeafList[iR][0]].name, (int)strlen(ppcReprsnt2[0]));
+                                piLeafCount[iR], (int)strlen(ppcCopy2[0]), prMSeq->sqinfo[ppiLeafList[iR][0]].name, 
+                                (int)strlen(ppcReprsnt2[0]), zcError);
                     }
                 }
                 pdScores[ppiLeafList[iR][0]] = dScore;
@@ -932,10 +934,11 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                      pcConsens1, pcReprsnt1,
                                      pcConsens2, pcReprsnt2,
                                      rHhalignPara, &rHHscores, 
-                                     iAux_FS++, /* DEBUG ARGUMENT */
+                                     iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                      zcAux, zcError);
 
                     if (RETURN_OK != iHHret){ /* FS, r241 -> */
+                        //fprintf(stderr, "%s:%d: emergency EXIT\n", __FILE__, __LINE__); exit(-1);
                         fprintf(stderr, 
                                 "%s:%s:%d: problem in alignment (profile sizes: %d + %d) (%s + %s), forcing Viterbi\n"
                                 "\thh-error-code=%d (mac-ram=%d)\n%s",
@@ -968,11 +971,11 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          pcConsens1, pcReprsnt1,
                                          pcConsens2, pcReprsnt2,
                                          rHhalignPara, &rHHscores, 
-                                         iAux_FS++, /* DEBUG ARGUMENT */
+                                         iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                          zcAux, zcError);
                         if (RETURN_OK != iHHret){ /* at this stage hhalign() has failed twice, 
                                              1st time MAC, 2nd time Viterbi, don't know what to do else. FS, r241 -> r243 */
-                            fprintf(stderr, "%s:%s:%d: problem in alignment, even Viterbi did not work\n"
+                            fprintf(stderr, "%s:%s:%d: problem in alignment, Viterbi did not work\n"
                                     "\thh-error-code=%d (mac-ram=%d)\n%s",
                                     __FUNCTION__, __FILE__, __LINE__, iHHret, rHhalignPara.iMacRamMB, zcError);
                             Log(&rLog, LOG_FATAL, "could not perform alignment -- bailing out\n");
@@ -993,10 +996,11 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                      pcConsens2, pcReprsnt2,
                                      pcConsens1, pcReprsnt1,
                                      rHhalignPara, &rHHscores, 
-                                     iAux_FS++, /* DEBUG ARGUMENT */
+                                     iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                      zcAux, zcError);
 
                     if (RETURN_OK != iHHret){ /* FS, r241 -> r243 */
+                        //fprintf(stderr, "%s:%d: emergency EXIT\n", __FILE__, __LINE__); exit(-1);
                         fprintf(stderr, 
                                 "%s:%s:%d: problem in alignment (profile sizes: %d + %d) (%s + %s), forcing Viterbi\n"
                                 "\thh-error-code=%d (mac-ram=%d)\n%s",
@@ -1021,11 +1025,11 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          pcConsens2, pcReprsnt2,
                                          pcConsens1, pcReprsnt1,
                                          rHhalignPara, &rHHscores, 
-                                         iAux_FS++, /* DEBUG ARGUMENT */
+                                         iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
                                          zcAux, zcError);
                         if (RETURN_OK != iHHret){ /* at this stage hhalign() has failed twice, 
                                              1st time MAC, 2nd time Viterbi, don't know what to do else. FS, r241 -> r243 */
-                            fprintf(stderr, "%s:%s:%d: problem in alignment, even Viterbi did not work\n"
+                            fprintf(stderr, "%s:%s:%d: problem in alignment, Viterbi did not work\n"
                                     "\thh-error-code=%d (mac-ram=%d)\n%s",
                                     __FUNCTION__, __FILE__, __LINE__, iHHret, rHhalignPara.iMacRamMB, zcError);
                             Log(&rLog, LOG_FATAL, "could not perform alignment -- bailing out\n");
