@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: seq.c 274 2012-04-24 23:28:24Z dave $
+ *  RCS $Id: seq.c 283 2013-06-10 17:42:14Z fabian $
  *
  *
  * Module for sequence/alignment IO and misc.
@@ -418,7 +418,7 @@ SeqTypeToStr(int iSeqType)
  */
 int
 ReadSequences(mseq_t *prMSeq, char *seqfile, 
-              int iSeqType, int iSeqFmt,
+              int iSeqType, int iSeqFmt, bool bIsProfile, 
               int iMaxNumSeq, int iMaxSeqLen)
 {
     SQFILE *dbfp; /* sequence file descriptor */
@@ -561,7 +561,7 @@ ReadSequences(mseq_t *prMSeq, char *seqfile,
 #endif*/
     
     /* Check if sequences are aligned */
-    prMSeq->aligned = SeqsAreAligned(prMSeq);
+    prMSeq->aligned = SeqsAreAligned(prMSeq, bIsProfile);
 
     
     /* keep original sequence as copy and convert "working" sequence
@@ -608,7 +608,10 @@ ReadSequences(mseq_t *prMSeq, char *seqfile,
         }
     }
 
-    
+    /* order in which sequences appear in guide-tree 
+     * only allocate if different output-order desired */
+    prMSeq->tree_order = NULL;
+
     prMSeq->filename = CkStrdup(seqfile);
     Log(&rLog, LOG_INFO, "Read %d sequences (type: %s) from %s",
          prMSeq->nseqs, SeqTypeToStr(prMSeq->seqtype), prMSeq->filename);
@@ -640,6 +643,7 @@ NewMSeq(mseq_t **prMSeq)
 	(*prMSeq)->seqtype = SEQTYPE_UNKNOWN;
 	(*prMSeq)->sqinfo = NULL;
 	(*prMSeq)->filename = NULL;
+	(*prMSeq)->tree_order = NULL;
 }
 /***   end: NewMSeq   ***/
 
@@ -756,6 +760,11 @@ FreeMSeq(mseq_t **mseq)
         CKFREE((*mseq)->sqinfo);
     }
 
+    /* FIXME (FS): problem with freeing tree_order */
+    if ((*mseq)->tree_order){
+        CKFREE((*mseq)->tree_order);
+    }
+
 	(*mseq)->seqtype = SEQTYPE_UNKNOWN;
 	(*mseq)->nseqs = 0;
 
@@ -773,6 +782,8 @@ FreeMSeq(mseq_t **mseq)
  * The name of the output file
  * @param[in] outfmt
  * The alignment output format (defined in squid.h)
+ * @param[in] iWrap
+ * length of line for Clustal/Fasta format
  *
  * @return Non-zero on error
  *
@@ -782,7 +793,7 @@ FreeMSeq(mseq_t **mseq)
  * 
  */    
 int
-WriteAlignment(mseq_t *mseq, const char *pcAlnOutfile, int outfmt)
+WriteAlignment(mseq_t *mseq, const char *pcAlnOutfile, int outfmt, int iWrap, bool bResno)
 {
     int i; /* aux */
     MSA *msa; /* squid's alignment structure */
@@ -820,9 +831,19 @@ WriteAlignment(mseq_t *mseq, const char *pcAlnOutfile, int outfmt)
      * messy when calling MSAFree()
      */
     for (i=0; i<mseq->nseqs; i++) {
-        char *this_name = mseq->sqinfo[i].name; /* mseq sequence name */
-        char *this_seq = mseq->seq[i]; /* mseq sequence */
-        SQINFO *this_sqinfo = &mseq->sqinfo[i]; /* mseq sequence name */
+        char *this_name = NULL; /* mseq sequence name */
+        char *this_seq = NULL; /* mseq sequence */
+        SQINFO *this_sqinfo = NULL; /* mseq sequence name */
+        int iI;
+
+        /* mseq->tree_order encodes to order in which sequences are listed in the guide-tree,
+           if the user wants the sequence output in the input-order then mseq->tree_order==NULL, 
+           otherwise mseq->tree_order!=NULL, containing the indices of the sequences, FS, r274 ->  */
+        iI = (NULL == mseq->tree_order) ? i : mseq->tree_order[i];
+
+        this_name = mseq->sqinfo[iI].name; /* mseq sequence name */
+        this_seq = mseq->seq[iI]; /* mseq sequence */
+        this_sqinfo = &mseq->sqinfo[iI]; /* mseq sequence name */
 
         key = GKIStoreKey(msa->index, this_name);
         msa->sqname[key] = sre_strdup(this_name, strlen(this_name));
@@ -842,7 +863,8 @@ WriteAlignment(mseq_t *mseq, const char *pcAlnOutfile, int outfmt)
          */
 
         msa->nseq++;
-    }    
+
+    } /* 0 <= i < mseq->nseqs */
 
 
     /* FIXME Would like to, but can't use MSAVerifyParse(msa) here, as it
@@ -864,13 +886,15 @@ WriteAlignment(mseq_t *mseq, const char *pcAlnOutfile, int outfmt)
     
     switch (outfmt) {
     case MSAFILE_A2M:
-        WriteA2M(pfOut, msa, 0);
+        //WriteA2M(pfOut, msa, 0);
+        WriteA2M(pfOut, msa, iWrap);
         break;
     case MSAFILE_VIENNA:
-        WriteA2M(pfOut, msa, 1);
+        //WriteA2M(pfOut, msa, 1);
+        WriteA2M(pfOut, msa, INT_MAX);
         break;
     case MSAFILE_CLUSTAL:
-        WriteClustal(pfOut, msa);
+        WriteClustal(pfOut, msa, iWrap, TRUE==bResno ? 1 : 0);
         break;
     case MSAFILE_MSF:
         WriteMSF(pfOut, msa);
@@ -997,7 +1021,7 @@ SortMSeqByLength(mseq_t *prMSeq, const char cOrder)
  * 
  */    
 bool
-SeqsAreAligned(mseq_t *prMSeq)
+SeqsAreAligned(mseq_t *prMSeq, bool bIsProfile)
 {
     bool bGapFound, bSameLength;
     int iSeqIdx; /* sequence counter */
@@ -1020,8 +1044,8 @@ SeqsAreAligned(mseq_t *prMSeq)
      */
     bGapFound = FALSE;
     bSameLength = TRUE;
-    for (iSeqIdx=0; iSeqIdx<prMSeq->nseqs; iSeqIdx++) {
-        if (FALSE == bGapFound) {
+    for (iSeqIdx=0; (iSeqIdx < prMSeq->nseqs); iSeqIdx++) {
+        if ( (FALSE == bGapFound) ){
             for (iSeqPos=0;
                  iSeqPos<prMSeq->sqinfo[iSeqIdx].len && false==bGapFound;
                  iSeqPos++) {
@@ -1031,7 +1055,7 @@ SeqsAreAligned(mseq_t *prMSeq)
                     break;
                 }
             }
-        }
+        } /* gap not (yet) found */
 
         if (iSeqIdx>0) {
             if (prMSeq->sqinfo[iSeqIdx].len != prMSeq->sqinfo[iSeqIdx-1].len) {
@@ -1041,17 +1065,17 @@ SeqsAreAligned(mseq_t *prMSeq)
                 break;
             }
         }
-    }
+    } /* 0 <= iSeqIdx < prMSeq->nseqs */
 #if 0
     Log(&rLog, LOG_FORCED_DEBUG, "bSameLength=%d bGapFound=%d", bSameLength, bGapFound);
 #endif
-    if (TRUE == bSameLength && TRUE == bGapFound) {
+    if ( (TRUE == bSameLength) && ((TRUE == bGapFound) || (TRUE == bIsProfile)) ) {
         return TRUE;
     } else {
         return FALSE;
     }   
 
-}
+} 
 /***   end: SeqsAreAligned()   ***/
 
 
@@ -1128,7 +1152,6 @@ AddSeq(mseq_t **prMSeqDest_p, char *pcSeqName, char *pcSeqRes)
  * MSeq structure to which to append to
  * @param[out] prMSeqToAdd
  * MSeq structure which is to append
- *
  * 
  */    
 void
@@ -1181,8 +1204,11 @@ JoinMSeqs(mseq_t **prMSeqDest_p, mseq_t *prMSeqToAdd)
     }
 
     (*prMSeqDest_p)->nseqs = iNewNSeq;
-    
-    (*prMSeqDest_p)->aligned = SeqsAreAligned(*prMSeqDest_p);
+
+    /* 2nd arg is bIsProfile, which when set TRUE skips 
+     * the check for gaps. here always check for gaps, 
+     * so set FALSE (main reason is that it is easier), FS, r282 -> */    
+    (*prMSeqDest_p)->aligned = SeqsAreAligned(*prMSeqDest_p, FALSE);
     
     return; 
 }
