@@ -13,7 +13,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: seq.h 270 2011-11-16 07:27:31Z andreas $
+ *  RCS $Id: seq.h 283 2013-06-10 17:42:14Z fabian $
  */
 
 #ifndef CLUSTALO_SEQ_H
@@ -62,6 +62,10 @@ typedef struct {
      */
     char **orig_seq;
     
+  /** order in which sequences appear in guide-tree
+   */
+  int *tree_order;
+
     /**
      * @brief Squid's sequence info structure.
      * Index range: 0--nseq-1.
@@ -126,7 +130,7 @@ SeqTypeToStr(int seqtype);
 
 extern int
 ReadSequences(mseq_t *prMSeq_p, char *pcSeqFile, 
-              int iSeqType,  int iSeqFmt,
+              int iSeqType,  int iSeqFmt, bool bIsProfile, 
               int iMaxNumSeq, int iMaxSeqLen);
 
 extern void
@@ -145,7 +149,7 @@ extern int
 FindSeqName(char *seqname, mseq_t *mseq);
 
 extern int
-WriteAlignment(mseq_t *mseq, const char *aln_outfile, int msafile_format);
+WriteAlignment(mseq_t *mseq, const char *aln_outfile, int msafile_format, int iWrap, bool bResno);
 
 extern void
 DealignSeq(char *seq);
@@ -160,6 +164,6 @@ void
 JoinMSeqs(mseq_t **prMSeqDest_p, mseq_t *prMSeqToAdd);
 
 bool
-SeqsAreAligned(mseq_t *prMSeq);
+SeqsAreAligned(mseq_t *prMSeq, bool bIsProfile);
 
 #endif
