@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign.cpp 274 2012-04-24 23:28:24Z dave $
+ *  RCS $Id: hhalign.cpp 284 2013-06-12 10:10:11Z fabian $
  */
 
 /* hhalign.C: 
@@ -681,7 +681,7 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
         char *pcPrealigned1, char *pcRepresent1, 
         char *pcPrealigned2, char *pcRepresent2, 
         hhalign_para rHhalignPara, hhalign_scores *rHHscores, 
-        int iFlag,
+        int iFlag, int iVerbosity, 
         char zcAux[], char zcError[]) {
 
 
@@ -1208,12 +1208,13 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
           }
           int iPrAliRtn = hitlist.PrintAlignments(
 #ifdef CLUSTALO
-                                                  ppcFirstProf, ppcSecndProf, 
+                                                  ppcFirstProf, ppcSecndProf, zcAux, zcError, 
 #endif
                                                   q, par.pairwisealisfile, par.outformat);
-          if (OK != iPrAliRtn){
-              fprintf(stderr, "%s:%s:%d: Could not print alignments\n",
+          if ( (OK != iPrAliRtn) ){
+              sprintf(zcAux, "%s:%s:%d: Could not print alignments\n",
                       __FUNCTION__, __FILE__, __LINE__);
+              strcat(zcError, zcAux);
               iRetVal = RETURN_FROM_PRINT_ALI; /* this is where mis-alignment was originally spotted, 
                                     hope to trap it now earlier. FS, r241 -> r243 */
               goto this_is_the_end;
@@ -1227,7 +1228,7 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
           hitlist.PrintHitList(q, par.outfile); 
           hitlist.PrintAlignments(
 #ifdef CLUSTALO
-                                  ppcFirstProf, ppcSecndProf, 
+                                  ppcFirstProf, ppcSecndProf, zcAux, zcError, 
 #endif
                                   q, par.outfile);
           if (v>=2) {
