@@ -15,9 +15,11 @@
  ********************************************************************/
 
 /*
- * RCS $Id: hhutil-C.h 274 2012-04-24 23:28:24Z dave $
+ * RCS $Id: hhutil-C.h 279 2013-05-16 15:55:15Z fabian $
  */
 
+#define PARAMETERSFROMFILE 0
+
 extern bool nucleomode;
  
 //////////////////////////////////////////////////////////////////////////////
@@ -702,6 +704,11 @@ SetDefaults()
   strcpy(par.psifile,""); 
   par.exclstr=NULL; 
 
+
+#if PARAMETERSFROMFILE  /* read parameter file from home-dir */
+#include "hhutil-C-help.h"
+#endif /* read parameter file from home-dir */
+
    return;
 } /** this is the end of SetDefaults() **/
 
@@ -719,7 +726,8 @@ void SetRnaDefaults()
   par.gapg=1.01;                // factor for increasing gap open penalty for inserts
   par.gaph=1.24;                // factor for increasing gap extension penalty for deletes
   par.gapi=0.45;                // factor for increasing gap extension penalty for inserts
-  
+
+#if 0  /* these are the parameters determined by Dave (pre r274) */
   par.pcaV=2.57f;                // default values for substitution matrix pseudocounts 
   par.pcbV=2.34f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
   par.pccV=0.88f;                // pcs are reduced prop. to 1/Neff^pcc
@@ -732,7 +740,26 @@ void SetRnaDefaults()
   par.gapgV=0.89;                // factor for increasing gap open penalty for inserts
   par.gaphV=0.54;                // factor for increasing gap extension penalty for deletes
   par.gapiV=0.86;                // factor for increasing gap extension penalty for inserts  
-}
+#else /* parameters determined for r274, using Bralibase, FS */
+  par.pcaV=1.655620f;                // default values for substitution matrix pseudocounts 
+  par.pcbV=0.438399f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
+  par.pccV=0.371491f;                // pcs are reduced prop. to 1/Neff^pcc
+  par.pcwV=0.0f;                // wc>0 weighs columns according to their intra-clomun similarity
+
+  par.gapbV=1.914490;                // default values for transition pseudocounts
+  par.gapdV=0.104278;               // gap open penalty pseudocount; 0.25 corresponds to 7.1*gapf bits
+  par.gapeV=1.100210;                // gap extension penalty pseudocount
+  par.gapfV=0.335152;                // factor for increasing gap open penalty for deletes
+  par.gapgV=0.786688;                // factor for increasing gap open penalty for inserts
+  par.gaphV=0.667143;                // factor for increasing gap extension penalty for deletes
+  par.gapiV=0.711993;                // factor for increasing gap extension penalty for inserts  
+#endif
+
+#if PARAMETERSFROMFILE  /* read parameter file from home-dir */
+#include "hhutil-C-help.h"
+#endif /* read parameter file from home-dir */
+
+} /* this is the end of SetRnaDefaults() */
 
 void SetDnaDefaults()
 {
@@ -749,6 +776,7 @@ void SetDnaDefaults()
   par.gaph=1.24;                // factor for increasing gap extension penalty for deletes
   par.gapi=0.45;                // factor for increasing gap extension penalty for inserts
   
+#if 0 /* these are the parameters determined by Dave (pre r274) */
   par.pcaV=1.712f;                // default values for substitution matrix pseudocounts 
   par.pcbV=1.039f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
   par.pccV=0.266f;                // pcs are reduced prop. to 1/Neff^pcc
@@ -761,7 +789,27 @@ void SetDnaDefaults()
   par.gapgV=2.025;                // factor for increasing gap open penalty for inserts
   par.gaphV=0.544;                // factor for increasing gap extension penalty for deletes
   par.gapiV=1.35;                // factor for increasing gap extension penalty for inserts }
-}
+#else /* parameters determined for r274, using mdsa, FS */
+  par.pcaV=2.196;                // default values for substitution matrix pseudocounts 
+  par.pcbV=0.329;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
+  par.pccV=0.393;                // pcs are reduced prop. to 1/Neff^pcc
+  par.pcwV=0.0f;                // wc>0 weighs columns according to their intra-clomun similarity
+
+  par.gapbV=0.570;                // default values for transition pseudocounts
+  par.gapdV=0.048;               // gap open penalty pseudocount; 0.25 corresponds to 7.1*gapf bits
+  par.gapeV=1.692;                // gap extension penalty pseudocount
+  par.gapfV=0.398;                // factor for increasing gap open penalty for deletes
+  par.gapgV=0.121;                // factor for increasing gap open penalty for inserts
+  par.gaphV=0.012;                // factor for increasing gap extension penalty for deletes
+  par.gapiV=0.645;                // factor for increasing gap extension penalty for inserts }
+#endif
+
+#if PARAMETERSFROMFILE  /* read parameter file from home-dir */
+#include "hhutil-C-help.h"
+#endif /* read parameter file from home-dir */
+
+} /* this is the end of SetDnaDefaults() */
+
 
 /*
  * EOF hhutil-C.h
